@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2021 Stefan Widgren
+## Copyright (C) 2015 -- 2022 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ NULL
 ##' package.
 ##' @noRd
 .onUnload <- function(libpath) {
-    library.dynam.unload("SimInf", libpath)
+    library.dynam.unload("SimInf", libpath) # nocov
 }
 
 ##' Example data with spatial distribution of nodes
