@@ -5,7 +5,7 @@
  * Copyright (C) 2015 Pavol Bauer
  * Copyright (C) 2017 -- 2019 Robin Eriksson
  * Copyright (C) 2015 -- 2019 Stefan Engblom
- * Copyright (C) 2015 -- 2021 Stefan Widgren
+ * Copyright (C) 2015 -- 2022 Stefan Widgren
  *
  * SimInf is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,7 +46,11 @@
  * Example:
  * end_t1, end_t2, end_t3, end_t4, index, value, index, value, -1, 0.0
  */
-SEXP attribute_hidden SimInf_ldata_sp(SEXP data, SEXP distance, SEXP metric)
+SEXP attribute_hidden
+SimInf_ldata_sp(
+    SEXP data,
+    SEXP distance,
+    SEXP metric)
 {
     SEXP result;
     double *val, *ldata, *ld;
